# Test Data

This directory contains test data files used by the test suite.

## Files

### `schema_original.py`

The **un-customized** version of the GraphQL schema as generated by `sgqlc-codegen schema`.

This file is used by tests to verify that the customization process works correctly.

**Important:** This file should be updated whenever the schema is regenerated from the API. The
GitHub Action workflow in the monolith repo should update this file as part of the schema generation
process. This is typically done during our automated updates.

The `update-test-schema` make target is used prior to running customizations to refresh this file.
